package library.ocl;

import java.io.File;
import org.eclipse.emf.common.util.Diagnostic;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
import org.eclipse.emf.ecore.util.Diagnostician;
import org.eclipse.emf.ecore.xmi.impl.XMIResourceFactoryImpl;
import org.eclipse.ocl.pivot.internal.utilities.PivotEnvironmentFactory;
import org.eclipse.ocl.pivot.resource.BasicProjectManager;
import org.eclipse.ocl.pivot.validation.ComposedEValidator;
import org.eclipse.ocl.xtext.completeocl.validation.CompleteOCLEObjectValidator;

import library.LibraryPackage;

public class CompleteOCLTest {

    public static void main( String[] args ) {
        ResourceSetImpl resourceSet = new ResourceSetImpl();
        resourceSet.getResourceFactoryRegistry().getExtensionToFactoryMap()
                .put( Resource.Factory.Registry.DEFAULT_EXTENSION, new XMIResourceFactoryImpl() );

        resourceSet.getPackageRegistry().put( LibraryPackage.eNS_URI, LibraryPackage.eINSTANCE );

        org.eclipse.ocl.xtext.completeocl.CompleteOCLStandaloneSetup.doSetup();

        PivotEnvironmentFactory environmentFactory = new PivotEnvironmentFactory( new BasicProjectManager(), null );
        ComposedEValidator validator = ComposedEValidator.install( LibraryPackage.eINSTANCE );

        Resource resource = resourceSet
                .getResource( URI.createFileURI( new File( "test/libtest.library" ).getAbsolutePath() ), true );

        CompleteOCLEObjectValidator v1 = new CompleteOCLEObjectValidator( LibraryPackage.eINSTANCE,
                URI.createFileURI( new File( "test/test1.ocl" ).getAbsolutePath() ), environmentFactory );
        validator.addChild( v1 );

        System.out.println( "===== TEST WITH 1 OCL FILE =====" );
        for( EObject eObject : resource.getContents() ) {
            Diagnostic diagnostic = Diagnostician.INSTANCE.validate( eObject );
            if( diagnostic.getSeverity() != Diagnostic.OK ) {
                System.out.println( diagnostic.getMessage() );
                for (Diagnostic child : diagnostic.getChildren()) {
                    System.out.println( child.getMessage() );
                }
            }
        }

        CompleteOCLEObjectValidator v2 = new CompleteOCLEObjectValidator( LibraryPackage.eINSTANCE,
                URI.createFileURI( new File( "test/test2.ocl" ).getAbsolutePath() ), environmentFactory );
        validator.addChild( v2 );

        System.out.println( "===== TEST WITH 2 OCL FILES =====" );
        for( EObject eObject : resource.getContents() ) {
            Diagnostic diagnostic = Diagnostician.INSTANCE.validate( eObject );
            if( diagnostic.getSeverity() != Diagnostic.OK ) {
                System.out.println( diagnostic.getMessage() );
                for (Diagnostic child : diagnostic.getChildren()) {
                    System.out.println( child.getMessage() );
                }
            }
        }

    }

}
